@@ -5,6 +5,7 @@ from CADETProcess import CADETProcessError
 from CADETProcess.dataStructure import Structure
 from CADETProcess.dataStructure import NdArray
 
+
 class Performance(Structure):
     """Class for storing the performance parameters after fractionation.
 
@@ -15,8 +16,10 @@ class Performance(Structure):
     RankedPerformance
 
     """
-    _performance_keys = ['mass', 'concentration', 'purity', 'recovery',
-        'productivity', 'eluent_consumption']
+    _performance_keys = [
+        'mass', 'concentration', 'purity', 'recovery',
+        'productivity', 'eluent_consumption'
+    ]
 
     mass = NdArray()
     concentration = NdArray()
@@ -25,9 +28,9 @@ class Performance(Structure):
     productivity = NdArray()
     eluent_consumption = NdArray()
 
-
-    def __init__(self, mass, concentration, purity, recovery,
-                 productivity, eluent_consumption):
+    def __init__(
+            self, mass, concentration, purity, recovery,
+            productivity, eluent_consumption):
         self.mass = mass
         self.concentration = concentration
         self.purity = purity
@@ -50,12 +53,13 @@ class Performance(Structure):
         return getattr(self, item)
 
     def __repr__(self):
-        return '{}(mass={}, concentration={}, purity={}, recovery={}, \
-                    productivity={}, eluent_consumption={}'.format(
-            self.__class__.__name__, np.array_repr(self.mass),
-            np.array_repr(self.concentration), np.array_repr(self.purity),
-            np.array_repr(self.recovery), np.array_repr(self.productivity),
-            np.array_repr(self.eluent_consumption))
+        return \
+            f'{self.__class__.__name__}(mass={np.array_repr(self.mass)}, '\
+            f'concentration={np.array_repr(self.concentration)}, '\
+            f'purity={np.array_repr(self.purity)}, '\
+            f'recovery={np.array_repr(self.recovery)}, '\
+            f'productivity={np.array_repr(self.productivity)}, '\
+            f'eluent_consumption={np.array_repr(self.eluent_consumption)})'
 
 
 class RankedPerformance():
@@ -83,7 +87,9 @@ class RankedPerformance():
         self._ranking = ranking
 
     def to_dict(self):
-        return {key: float(getattr(self, key)) for key in self._performance_keys}
+        return {
+            key: float(getattr(self, key)) for key in self._performance_keys
+        }
 
     def __getattr__(self, item):
         if item not in self._performance_keys:
@@ -96,19 +102,21 @@ class RankedPerformance():
         return getattr(self, item)
 
     def __repr__(self):
-        return '{}(mass={}, concentration={}, purity={}, recovery={}, \
-                    productivity={}, eluent_consumption={}'.format(
-            self.__class__.__name__, np.array_repr(self.mass),
-            np.array_repr(self.concentration), np.array_repr(self.purity),
-            np.array_repr(self.recovery), np.array_repr(self.productivity),
-            np.array_repr(self.eluent_consumption))
+        return \
+            f'{self.__class__.__name__}(mass={np.array_repr(self.mass)}, '\
+            f'concentration={np.array_repr(self.concentration)}, '\
+            f'purity={np.array_repr(self.purity)}, '\
+            f'recovery={np.array_repr(self.recovery)}, '\
+            f'productivity={np.array_repr(self.productivity)}, '\
+            f'eluent_consumption={np.array_repr(self.eluent_consumption)})'
+
 
 def get_bad_performance(n_comp):
     return Performance(
-            mass = np.zeros((n_comp,)),
-            concentration = np.zeros((n_comp,)),
-            purity = np.zeros((n_comp,)),
-            recovery = np.zeros((n_comp,)),
-            productivity = np.zeros((n_comp,)),
-            eluent_consumption = np.zeros((n_comp,)),
-            )
+        mass=np.zeros((n_comp,)),
+        concentration=np.zeros((n_comp,)),
+        purity=np.zeros((n_comp,)),
+        recovery=np.zeros((n_comp,)),
+        productivity=np.zeros((n_comp,)),
+        eluent_consumption=np.zeros((n_comp,)),
+    )
