@@ -8,7 +8,34 @@ from CADETProcess.processModel import FlowSheet
 from CADETProcess.processModel import Process
 from CADETProcess.simulation import Cadet
 
-def simulate_solid_equilibria(binding_model, buffer, unit_model='cstr', flush=None):
+
+def simulate_solid_equilibria(
+        binding_model, buffer, unit_model='cstr', flush=None):
+    """Simulate initial conditions for solid phase for given buffer.
+
+    Parameters
+    ----------
+    binding_model : BindingBase
+        Binding model describing relation between bulk and solif phase.
+    buffer : list
+        Buffer concentration in mM.
+    unit_model : {'cstr', 'column'}, optional
+        Unit model to be used in simulation. The default is 'cstr'.
+    flush : list, optional
+        Additional buffer for flushing column after loading.
+        The default is None.
+
+    Raises
+    ------
+    CADETProcessError
+        DESCRIPTION.
+
+    Returns
+    -------
+    list
+        Initial conditions for solid phase.
+
+    """
     process_name = flow_sheet_name = 'initial_conditions'
     component_system = binding_model.component_system
 
@@ -39,7 +66,7 @@ def simulate_solid_equilibria(binding_model, buffer, unit_model='cstr', flush=No
         Q = 60/(60*1e6)
         cycle_time = np.round(10*unit.volume/Q)
     else:
-        raise CADETProcessError("Unknown unit model for initial conditions")
+        raise CADETProcessError("Unknown unit model")
 
     try:
         q = binding_model.n_comp * binding_model.n_states * [0]
@@ -75,24 +102,28 @@ def simulate_solid_equilibria(binding_model, buffer, unit_model='cstr', flush=No
     proc = Process(fs, name=process_name)
     proc.cycle_time = cycle_time
 
-    ## Create Events and Durations
+    # Create Events and Durations
     proc.add_event('buffer_on', 'flow_sheet.buffer.flow_rate', Q)
-    proc.add_event('buffer_off', 'flow_sheet.buffer.flow_rate', 0, 0.9*cycle_time)
+    proc.add_event(
+        'buffer_off', 'flow_sheet.buffer.flow_rate', 0, 0.9*cycle_time
+    )
 
     proc.add_event('eluent_off', 'flow_sheet.flush.flow_rate', 0.0, 0.0)
-    proc.add_event('eluent_on', 'flow_sheet.flush.flow_rate', Q, 0.9*cycle_time)
+    proc.add_event(
+        'eluent_on', 'flow_sheet.flush.flow_rate', Q, 0.9*cycle_time
+    )
 
     # Simulator
     process_simulator = Cadet()
     process_simulator.unit_return_parameters.write_solution_bulk = True
     process_simulator.unit_return_parameters.write_solution_solid = True
 
-    proc_results = process_simulator.run(proc)
+    proc_results = process_simulator.simulate(proc)
 
     if unit_model == 'cstr':
-        init_q = proc_results.solution[unit.name].solid.solution[-1,:]
+        init_q = proc_results.solution[unit.name].solid.solution[-1, :]
     elif unit_model == 'column':
-        init_q = proc_results.solution[unit.name].solid.solution[-1,0,:]
+        init_q = proc_results.solution[unit.name].solid.solution[-1, 0, :]
 
     init_q = np.round(init_q, 14)
     return init_q.tolist()
