@@ -25,23 +25,28 @@ def jacrow_scale(jacMat, scale):
     return jacMat / scale[:, None]
 
 
-def ptc(x, f, jacF, tau, tol, scale=None, maxIter=50, maxNonMonotone=5, quiet=True, variant=False):
+def ptc(
+        x, f, jacF, tau, tol,
+        scale=None, maxIter=50, maxNonMonotone=5,
+        quiet=True, variant=False):
     """
-    Solves a nonlinear equation system using pseudo-transient continuation.
+    Solve a nonlinear equation system using pseudo-transient continuation.
 
-    The nonlinear equation system f(x) = 0 is solved using pseudo-transient continuation (PTC),
-    which introduce pseudo time and computes the steady state of the ODE
-    dx / dt = f(x).
+    The nonlinear equation system f(x) = 0 is solved using pseudo-transient
+    continuation (PTC), which introduce pseudo time and computes the steady
+    state of the ODE dx / dt = f(x).
 
-    After resolving the transient regime at the beginning of the time integration, PTC
-    quickly increases the time step size to arrive at the equilibrium. It can be interpreted
-    as a linear-implicit Euler scheme for the ODE, which tends to a Newton method as the
-    time step size increases.
+    After resolving the transient regime at the beginning of the time
+    integration, PTC quickly increases the time step size to arrive at the
+    equilibrium. It can be interpreted as a linear-implicit Euler scheme for
+    the ODE, which tends to a Newton method as the time step size increases.
 
-    The step size is adaptively determined by switched evolution relaxation (SER).
+    The step size is adaptively determined by switched evolution relaxation
+    (SER).
 
-    See Deuflhard, Peter (2011). Newton Methods for Nonlinear Problems (Vol. 35).
-    Berlin, Heidelberg: Springer. http://doi.org/10.1007/978-3-642-23899-4
+    See Deuflhard, Peter (2011). Newton Methods for Nonlinear Problems
+    (Vol. 35). Berlin, Heidelberg: Springer.
+    http://doi.org/10.1007/978-3-642-23899-4
 
     Args:
         x: Initial point as numpy array
@@ -49,18 +54,26 @@ def ptc(x, f, jacF, tau, tol, scale=None, maxIter=50, maxNonMonotone=5, quiet=Tr
         jacF: Function with signature jacF(x) that returns the Jacobian of f
         tau: Initial pseudo time step size
         tol: Target tolerance for scaled root mean square residual
-        scale: A numpy vector with (positive) diagonal scaling coefficients or None
-            if no scaling is applied. The scaled root mean square norm is given by
+        scale: A numpy vector with (positive) diagonal scaling coefficients or
+        None if no scaling is applied.
+        The scaled root mean square norm is given by
             || x || = \sqrt{ (1/n) * \sum (x_i / v_i)^2}
         maxIter: Maximum number of iterations
-        maxNonMonotone: Maximum number of iterations with non-decreasing residual in a row
-        quiet: Determines whether iteration number, norm of step, scaled root mean
-            square residual, and step size are printed on each iteration.
-        variant: Determines whether (1/tau * I - F'(x)) * dx = F(x) is solved (True) or
+        maxNonMonotone: Maximum number of iterations with non-decreasing 
+            residual in a row
+        quiet: Determines whether iteration number, norm of step, scaled root
+            mean square residual, and step size are printed on each iteration.
+        variant: Determines whether
+            (1/tau * I - F'(x)) * dx = F(x) is solved (True)
+            or
             (I - tau * F'(x)) * dx = F(x) is solved (False).
 
     Returns:
-        tuple: (Status code, solution as numpy vector, scaled root mean square residual)
+        tuple: (
+            Status code,
+            solution as numpy vector,
+            scaled root mean square residual
+        )
             The status code determines whether the algorithm succeeded:
                 -2: Failed due to non-decreasing residual
                 -1: Failed due to singular Jacobian
@@ -89,10 +102,12 @@ def ptc(x, f, jacF, tau, tol, scale=None, maxIter=50, maxNonMonotone=5, quiet=Tr
         jacMat = jacrow_scale(jacMat, scale)
 
         if variant:
-            # Solve scaled system (1/tau * I - F'(x)) * dx = F(x), update x <- x + dx
+            # Solve scaled system
+            # (1/tau * I - F'(x)) * dx = F(x), update x <- x + dx
             jacQ, jacR = scipy.linalg.qr(np.diag(1 / (tau * scale)) - jacMat)
         else:
-            # Solve scaled system (I - tau * F'(x)) * dx = F(x), update x <- x + tau * dx
+            # Solve scaled system
+            # (I - tau * F'(x)) * dx = F(x), update x <- x + tau * dx
             jacQ, jacR = scipy.linalg.qr(np.diag(1 / scale) - tau * jacMat)
 
         dx = fxk / scale
