@@ -7,20 +7,21 @@ from CADETProcess import CADETProcessError
 from CADETProcess.dataStructure import Structure, StructMeta
 from CADETProcess.dataStructure import String, Integer, UnsignedFloat
 
+
 class ComponentSystem(metaclass=StructMeta):
     name = String()
 
     def __init__(
             self, components=None, name=None,
-            charges=None, molecular_weights=None
-            ):
+            charges=None, molecular_weights=None):
         self.name = name
 
         self._components = []
 
         if components is None:
             return
-        elif isinstance(components, int):
+
+        if isinstance(components, int):
             n_comp = components
             components = n_comp*[None]
         elif isinstance(components, list):
@@ -34,11 +35,19 @@ class ComponentSystem(metaclass=StructMeta):
             molecular_weights = n_comp * [None]
 
         for i, comp in enumerate(components):
-            self.add_component(
-                species=comp,
-                charge=charges[i],
-                molecular_weight=molecular_weights[i]
-            )
+
+            if isinstance(comp, list):
+                self.add_component(
+                    species=comp,
+                    charge=charges[i],
+                    molecular_weight=molecular_weights[i]
+                )
+            else:
+                self.add_component(
+                    name=comp,
+                    charge=charges[i],
+                    molecular_weight=molecular_weights[i]
+                )
 
     @property
     def components(self):
@@ -71,7 +80,12 @@ class ComponentSystem(metaclass=StructMeta):
 
     @property
     def names(self):
-        return [comp.name for comp in self.components]
+        names = [
+            comp.name if comp.name is not None else i
+            for i, comp in enumerate(self.components)
+        ]
+
+        return names
 
     @property
     def labels(self):
@@ -82,7 +96,7 @@ class ComponentSystem(metaclass=StructMeta):
                 if label is None:
                     labels.append(str(index))
                 else:
-                   labels.append(label)
+                    labels.append(label)
 
                 index += 1
 
@@ -104,42 +118,18 @@ class ComponentSystem(metaclass=StructMeta):
 
         return molecular_weights
 
-    def total_concentration(self, solution):
-        """Compute total concentration of components by summing up species.
-
-        Parameters
-        ----------
-        solution : np.array
-            Solution array.
-
-        Returns
-        -------
-        total_concentration : np.array
-            Total concentration of components.
-
-        """
-        total_concentration = np.zeros(
-            solution.shape[0:-1] + (self.n_components,)
-        )
-
-        counter = 0
-        for index, comp in enumerate(self.components):
-            comp_indices = slice(counter, counter+comp.n_species)
-            total_concentration[:,index] = np.sum(solution[...,comp_indices], axis=1)
-            counter += comp.n_species
-
-        return total_concentration
-    
     def __repr__(self):
         return f'{self.__class__.__name__}({self.names})'
 
+    def __iter__(self):
+        yield from self.components
+
 
 class Component(metaclass=StructMeta):
     name = String()
 
     def __init__(
-            self, name=None, species=None, charge=None, molecular_weight=None
-            ):
+            self, name=None, species=None, charge=None, molecular_weight=None):
         self.name = name
         self._species = []
 
@@ -181,6 +171,10 @@ class Component(metaclass=StructMeta):
     def molecular_weight(self):
         return [spec.molecular_weight for spec in self.molecular_weight]
 
+    def __iter__(self):
+        yield from self.species
+
+
 class Species(Structure):
     name = String()
     charge = Integer(default=0)
